#!/usr/bin/env python3
import sys, time
import pywinauto, warnings
warnings.filterwarnings('ignore')

PAUSE = 0.5

def move_w(mazesolver_w, ventmaze_doc, w, h):
	if ventmaze_doc is not None:
		x = int(0.50 * w + 0.01 * h)
		y = int(0.40 * h - 0.01 * h)
		ventmaze_doc.set_focus()
		ventmaze_doc.click_input(coords = (x, y))
	mazesolver_w.type_keys('w')

def move_a(mazesolver_w, ventmaze_doc, w, h):
	if ventmaze_doc is not None:
		x = int(0.10 * w + 0.01 * w)
		y = int(0.45 * h + 0.01 * h)
		ventmaze_doc.set_focus()
		ventmaze_doc.click_input(coords = (x, y))
	mazesolver_w.type_keys('a')

def move_s(mazesolver_w, ventmaze_doc, w, h):
	if ventmaze_doc is not None:
		x = int(0.50 * w + 0.01 * w)
		y = int(0.85 * h + 0.01 * h)
		ventmaze_doc.set_focus()
		ventmaze_doc.click_input(coords = (x, y))
	mazesolver_w.type_keys('s')

def move_d(mazesolver_w, ventmaze_doc, w, h):
	if ventmaze_doc is not None:
		x = int(w - (0.10 * w + 0.01 * w))
		y = int(0.45 * h + 0.01 * h)
		ventmaze_doc.set_focus()
		ventmaze_doc.click_input(coords = (x, y))
	mazesolver_w.type_keys('d')

def main():
	ventmaze = None
	mazesolver = None
	
	if len(sys.argv) < 2 or int(sys.argv[1]) not in (1,2):
		print('usage: {0} <floor> [<google>]')
		print('\n\t<floor>  - maze floor number (1|2)')
		print('\t<google> - click on real Ventilation Maze (0|1)')
		sys.exit(1)
	floor_nr = int(sys.argv[1])
	google = int(sys.argv[2]) if len(sys.argv) > 2 else 0
	google = True if google > 0 else False
	
	if floor_nr == 1:
		keys = 'wwwwwwdwwawwwwdwwwwdwwwwwwawwawwdwwawwdwwwwawwdwwawwwwdwwawwwwwwawwdwwdww'
	else:
		keys = 'dwwwwwwwwdwwwwwwdwwawwdwwawwwwawwwwwwwwawwdwwawwdwwwwwwawwwwdwwdww'
	
	for h in pywinauto.findwindows.enum_windows():
		title = (pywinauto.handleprops.text(h) or '').lower()
		if title.startswith('ventilation maze'):
			ventmaze = app = pywinauto.Application(backend='uia').connect(handle=h)
		if title.startswith('maze solver'):
			mazesolver = app = pywinauto.Application(backend='uia').connect(handle=h)

	if google and ventmaze is None:
		print('ventilation maze not found')
		sys.exit(1)
	if mazesolver is None:
		print('maze solver not found')
		sys.exit(1)
	
	mazesolver_w = mazesolver.window(title_re='Maze Solver.*')
	if google:
		ventmaze_w = ventmaze.window(title_re='Ventilation Maze.*')
		ventmaze_doc = ventmaze_w.Document0.Custom0
		ventmaze_rect = ventmaze_doc.rectangle()
		ventmaze_width = (ventmaze_rect.right - 17) - ventmaze_rect.left
		ventmaze_height = ventmaze_rect.bottom - ventmaze_rect.top
	else:
		ventmaze_doc = None
		ventmaze_width = 0
		ventmaze_height = 0
	
	if google:
		ventmaze_w.set_focus()
	mazesolver_w.set_focus()
	if google:
		time.sleep(PAUSE)
	mazesolver_w.set_focus()
	mazesolver_w.type_keys('r')
	for k in keys:
		print('move[{0}]'.format(k))
		if k == 'w':
			move_w(mazesolver_w, ventmaze_doc, ventmaze_width, ventmaze_height)
		elif k == 'a':
			move_a(mazesolver_w, ventmaze_doc, ventmaze_width, ventmaze_height)
		elif k == 's':
			move_s(mazesolver_w, ventmaze_doc, ventmaze_width, ventmaze_height)
		elif k == 'd':
			move_d(mazesolver_w, ventmaze_doc, ventmaze_width, ventmaze_height)
		if google:
			time.sleep(PAUSE)
			ventmaze.wait_cpu_usage_lower(threshold=5)

if __name__ == "__main__":
	main()
